@@ -44,4 +44,4 @@ class Audience(ff.AggregateRoot):
 
     def add_member(self, contact: domain.Contact):
         if self.get_member_by_contact(contact) is None:
-            self.members.append(domain.AudienceMember(contact=contact.id))
+            self.members.append(domain.AudienceMember(contact=contact))
